# no code
## no critic: TestingAndDebugging::RequireUseStrict
package TableDataBundle::Business::ID::DGIP;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2023-02-07'; # DATE
our $DIST = 'TableDataBundle-Business-ID-DGIP'; # DIST
our $VERSION = '20230207.0.0'; # VERSION

1;
# ABSTRACT: Collection of TableData:: modules related to the Directorate General of Intellectual Property

__END__

=pod

=encoding UTF-8

=head1 NAME

TableDataBundle::Business::ID::DGIP - Collection of TableData:: modules related to the Directorate General of Intellectual Property

=head1 VERSION

This document describes version 20230207.0.0 of TableDataBundle::Business::ID::DGIP (from Perl distribution TableDataBundle-Business-ID-DGIP), released on 2023-02-07.

=head1 DESCRIPTION

This distribution contains the following L<TableData>:: modules:

=over

=item * L<TableData::Business::ID::DGIP::Class>

=item * L<TableData::Business::ID::DGIP::Class::1>

=item * L<TableData::Business::ID::DGIP::Class::10>

=item * L<TableData::Business::ID::DGIP::Class::11>

=item * L<TableData::Business::ID::DGIP::Class::12>

=item * L<TableData::Business::ID::DGIP::Class::13>

=item * L<TableData::Business::ID::DGIP::Class::14>

=item * L<TableData::Business::ID::DGIP::Class::15>

=item * L<TableData::Business::ID::DGIP::Class::16>

=item * L<TableData::Business::ID::DGIP::Class::17>

=item * L<TableData::Business::ID::DGIP::Class::18>

=item * L<TableData::Business::ID::DGIP::Class::19>

=item * L<TableData::Business::ID::DGIP::Class::2>

=item * L<TableData::Business::ID::DGIP::Class::20>

=item * L<TableData::Business::ID::DGIP::Class::21>

=item * L<TableData::Business::ID::DGIP::Class::22>

=item * L<TableData::Business::ID::DGIP::Class::23>

=item * L<TableData::Business::ID::DGIP::Class::24>

=item * L<TableData::Business::ID::DGIP::Class::25>

=item * L<TableData::Business::ID::DGIP::Class::26>

=item * L<TableData::Business::ID::DGIP::Class::27>

=item * L<TableData::Business::ID::DGIP::Class::28>

=item * L<TableData::Business::ID::DGIP::Class::29>

=item * L<TableData::Business::ID::DGIP::Class::3>

=item * L<TableData::Business::ID::DGIP::Class::30>

=item * L<TableData::Business::ID::DGIP::Class::31>

=item * L<TableData::Business::ID::DGIP::Class::32>

=item * L<TableData::Business::ID::DGIP::Class::33>

=item * L<TableData::Business::ID::DGIP::Class::34>

=item * L<TableData::Business::ID::DGIP::Class::35>

=item * L<TableData::Business::ID::DGIP::Class::36>

=item * L<TableData::Business::ID::DGIP::Class::37>

=item * L<TableData::Business::ID::DGIP::Class::38>

=item * L<TableData::Business::ID::DGIP::Class::39>

=item * L<TableData::Business::ID::DGIP::Class::4>

=item * L<TableData::Business::ID::DGIP::Class::40>

=item * L<TableData::Business::ID::DGIP::Class::41>

=item * L<TableData::Business::ID::DGIP::Class::42>

=item * L<TableData::Business::ID::DGIP::Class::43>

=item * L<TableData::Business::ID::DGIP::Class::44>

=item * L<TableData::Business::ID::DGIP::Class::45>

=item * L<TableData::Business::ID::DGIP::Class::5>

=item * L<TableData::Business::ID::DGIP::Class::6>

=item * L<TableData::Business::ID::DGIP::Class::7>

=item * L<TableData::Business::ID::DGIP::Class::8>

=item * L<TableData::Business::ID::DGIP::Class::9>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/TableDataBundle-Business-ID-DGIP>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-TableDataBundle-Business-ID-DGIP>.

=head1 SEE ALSO

L<TableData>

L<https://dgip.go.id>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 CONTRIBUTING


To contribute, you can send patches by email/via RT, or send pull requests on
GitHub.

Most of the time, you don't need to build the distribution yourself. You can
simply modify the code, then test via:

 % prove -l

If you want to build the distribution (e.g. to try to install it locally on your
system), you can install L<Dist::Zilla>,
L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
that are considered a bug and can be reported to me.

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2023, 2022 by perlancar <perlancar@cpan.org>.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=TableDataBundle-Business-ID-DGIP>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=cut
